
# Slot: precedence


the relative order in which the rule is applied

URI: [linkml:precedence](https://w3id.org/linkml/precedence)


## Domain and Range

None &#8594;  <sub>0..1</sub> integer

## Parents


## Children


## Used by

 * class_rule

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | sh:order |

